pub struct RustPlanSummary {Show 22 fields
pub operation: RustPlanOperation,
pub mode: RustPlanMode,
pub plan_schema_version: u32,
pub cache_schema_version: u32,
pub compatibility: RustPlanCompatibility,
pub restored_file_count: u64,
pub restored_bytes: u64,
pub saved_file_count: u64,
pub saved_bytes: u64,
pub skipped_count: u64,
pub skipped_reasons: BTreeMap<String, u64>,
pub skipped_samples: Vec<RustPlanSkippedSample>,
pub key_input_mismatches: Vec<String>,
pub miss_classifications: BTreeMap<String, u64>,
pub backend: String,
pub cache_key: String,
pub backend_cache_key: Option<String>,
pub backend_cache_version: Option<String>,
pub archive_path: Option<NormalizedPath>,
pub journal_log_path: Option<NormalizedPath>,
pub target_artifact_effectiveness: RustPlanArtifactEffectiveness,
pub compile_cache_stats: Option<Value>,
}Expand description
Machine-readable operation summary for soldr/setup-soldr.
Fields
operation: RustPlanOperationmode: RustPlanModeplan_schema_version: u32cache_schema_version: u32compatibility: RustPlanCompatibilityrestored_file_count: u64restored_bytes: u64saved_file_count: u64saved_bytes: u64skipped_count: u64skipped_reasons: BTreeMap<String, u64>skipped_samples: Vec<RustPlanSkippedSample>key_input_mismatches: Vec<String>miss_classifications: BTreeMap<String, u64>backend: Stringcache_key: Stringbackend_cache_key: Option<String>backend_cache_version: Option<String>archive_path: Option<NormalizedPath>journal_log_path: Option<NormalizedPath>target_artifact_effectiveness: RustPlanArtifactEffectivenesscompile_cache_stats: Option<Value>Implementations
Sourceimpl RustPlanSummary
impl RustPlanSummary
Sourcepub fn validation_success(plan: &RustArtifactPlanV1, cache_dir: &Path) -> Self
pub fn validation_success(plan: &RustArtifactPlanV1, cache_dir: &Path) -> Self
Create a validation-only success summary.
Sourcepub fn compatibility_failure(
operation: RustPlanOperation,
err: &RustPlanError,
) -> Self
pub fn compatibility_failure( operation: RustPlanOperation, err: &RustPlanError, ) -> Self
Create a compatibility failure summary for JSON CLI output.
Sourcepub fn record_skip(&mut self, path: impl Into<String>, reason: &'static str)
pub fn record_skip(&mut self, path: impl Into<String>, reason: &'static str)
Record a skipped artifact or backend miss in an operation summary.
Sourcepub fn set_backend(
&mut self,
backend: impl Into<String>,
backend_cache_key: Option<String>,
backend_cache_version: Option<String>,
)
pub fn set_backend( &mut self, backend: impl Into<String>, backend_cache_key: Option<String>, backend_cache_version: Option<String>, )
Set the backend identity fields in an operation summary.
Sourcepub fn refresh_miss_classifications(&mut self)
pub fn refresh_miss_classifications(&mut self)
Recompute low-reuse classifications from already-recorded diagnostics.
pub fn computed_miss_classifications(&self) -> BTreeMap<String, u64>